'use strict';

function setupContentsReflector(reflectortab, reflectorInfo) {
    const handler = (data) => {
        updateContentsReflector(reflectortab, data);
    };

    noraapi.addEventHandler(
        "update_status_" + reflectorInfo.webSocketRoomId,
        handler
    );
}

function updateContentsReflector(reflectorTab, data) {
    logger.trace(
        "Update contents reflector.\n" +
        JSON.stringify(data)
    );

    reflectorTab.empty();

    const connectionsId = data.webSocketRoomId + '.connections';
    reflectorTab.loadTemplate(
        $("#template_reflector"),
        {
            "contents_id" : data.webSocketRoomId,
            "reflector_type" : data.reflectorType,
            "connections_id" : connectionsId
        }
    );

    const connections = $('#' + selectorEscape(connectionsId));
    if(connections.exists()){
        data.connections.forEach(connectionInfo => {
            const extraContentsId = connectionsId + '.' + connectionInfo.connectionId;

            connections.loadTemplate(
                $('#template_reflector_connection'),
                {
                    "title" :
                        connectionInfo.reflectorCallsign + ' <-> ' +
                        connectionInfo.repeaterCallsign,
                    "id" : connectionInfo.connectionId,
                    "direction" : connectionInfo.connectionDirection,
                    "reflector_callsign" : connectionInfo.reflectorCallsign,
                    "repeater_callsign" : connectionInfo.repeaterCallsign,
                    "extra_contents_id" : extraContentsId
                },
                {'append':true}
            );

            const extraContents = $('#' + selectorEscape(extraContentsId));
            if(extraContents.exists()){
                if(data.reflectorType === 'JARLLink')
                    updateReflectorExtraContentsJARLLink(extraContents, connectionInfo);
            }
        });
    }
}

function updateReflectorExtraContentsJARLLink(extraContents, connectionInfo) {
    const callsigns =
        $('<div />', {
            "class":"d-flex flex-column flex-wrap",
            "style":'max-height: 200px;'
        });
    connectionInfo.loginClients.forEach((client) =>{
        callsigns.append($('<p />',{"text":client.callsign}));
    });

    extraContents.append(
        $('<h5 />',{"class" : "card-title", "text" : "Repeater Link State"}),
        $('<p />',{
            "text" : (connectionInfo.extraRepeaterLinked ? "Linked" : "Not Linked"),
            "class" :
                'font-weight-bold ' +
                (connectionInfo.extraRepeaterLinked ? "text-success" : "text-danger")
        }),
        $('<h5 />',{"class" : "card-title", "text" : "Server Software"}),
        $('<p />',{"text" : connectionInfo.serverSoftware}),
        $('<h5 />',{"class" : "card-title", "text" : "Connected Callsigns"}),
        callsigns
    );
}
